## Figure 1
Plots on the left correspond to the DMPC bilayer and plots on the right to the DPPC/RaLPS bilayer. Shown (_a_ and _b_) are the plots of minimum eigenvalue versus bulk water contrast SLD for the bilayer models, for the simultaneous choice of two contrasts assuming no prior measurement. Also shown are the nested sampling corner plots from sampling simulated data of solely D2O (_c_ and _d_) and simulated data of D2O and H2O (_g_ and _h_). Insets are the fitted SLD profiles (_e_ and _f_) and reflectivity curves (_i_ and _j_) for the experimentally-measured data sets of the two models. For clarity, the H2O and D2O DMPC bilayer data sets have been offset by factors of 10<sup>-2</sup> and 10<sup>-4</sup> respectively. The H2O and SMW DPPC/RaLPS data sets have been offset by the same factors, respectively.

<img src="https://github.com/James-Durant/experimental-design/blob/master/figures/figure_1_low_res.png" width="900">

## Figure 2
Minimum eigenvalue versus bulk water contrast SLD for the DMPC (blue) and DPPC/RaLPS (green) bilayer models, for a third contrast choice, assuming D2O and H2O have been previously measured.

<img src="https://github.com/James-Durant/experimental-design/blob/master/figures/figure_2_low_res.png" width="600">

## Figure 3
Plots on the left correspond to the DMPC bilayer and plots on the right to the DPPC/RaLPS bilayer. Shown (_a_ and _b_) are the plots of minimum eigenvalue versus underlayer SLD and underlayer thickness for the bilayer models, assuming D2O and H2O are being measured. Also shown are the nested sampling corner plots from sampling simulated data of D2O and H2O without any underlayer (_c_ and _d_) and with a single underlayer (_e_ and _f_).

<img src="https://github.com/James-Durant/experimental-design/blob/master/figures/figure_3_low_res.png" width="900">

## Figure 4
Shown are the model SLD profiles for the d-DPPG monolayer on NRW, h-DPPG on NRW and h-DPPG on D2O (_a_). Also shown are the plots of Fisher information in the lipid APM versus contrast SLD and measurement angle for the h-DPPG monolayer (_b_) and d-DPPG monolayer (_c_) models.

<img src="https://github.com/James-Durant/experimental-design/blob/master/figures/figure_4_low_res.png" width="500">

## Figure 5
Fisher information in the platinum layer magnetic SLD versus YIG and platinum layer thicknesses (_a_). Also shown are the experimentally-fitted SLD and reflectivity profiles (_b_ and _c_ respectively). Finally is the log ratio of likelihoods between two models, one with an induced moment in the platinum layer and one with no moment, versus counting time (_d_) for two structures: one with an optimised 26Å platinum layer thickness and the other with a sub-optimal 80Å thickness. The counting times shown are minutes per measured spin state (i.e., for this model, the total times are double the values shown here).

<img src="https://github.com/James-Durant/experimental-design/blob/master/figures/figure_5_low_res.png" width="800">
